@@ -19,15 +19,21 @@
 package org.sejda.core.service;
 
 import static org.apache.commons.lang3.RandomStringUtils.randomAlphanumeric;
-import static org.hamcrest.MatcherAssert.assertThat;
-import static org.hamcrest.Matchers.containsString;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.fail;
 import static org.mockito.Matchers.any;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 import static org.sejda.util.RequireUtils.requireNotBlank;
 
+import java.io.BufferedOutputStream;
+import java.io.File;
+import java.io.FileOutputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.util.ArrayList;
+import java.util.List;
+
 import org.apache.commons.io.FilenameUtils;
 import org.apache.commons.io.IOUtils;
 import org.junit.After;
@@ -36,7 +42,6 @@ import org.junit.Ignore;
 import org.sejda.TestUtils;
 import org.sejda.core.context.DefaultSejdaContext;
 import org.sejda.core.context.SejdaContext;
-import org.sejda.core.support.util.StringUtils;
 import org.sejda.model.exception.TaskException;
 import org.sejda.model.exception.TaskIOException;
 import org.sejda.model.input.FileSource;
@@ -49,16 +54,7 @@ import org.sejda.model.task.Task;
 import org.sejda.sambox.cos.COSName;
 import org.sejda.sambox.pdmodel.PDDocument;
 import org.sejda.sambox.pdmodel.PDPage;
-import org.sejda.sambox.pdmodel.common.PDRectangle;
 import org.sejda.sambox.pdmodel.graphics.image.PDImageXObject;
-import org.sejda.sambox.text.PDFTextStripperByArea;
-
-import java.awt.*;
-import java.io.*;
-import java.util.ArrayList;
-import java.util.Iterator;
-import java.util.List;
-import java.util.function.Consumer;
 
 /**
  * @author Andrea Vacondio
@@ -151,6 +147,16 @@ public abstract class BaseTaskTest<T extends TaskParameters> implements Testable
         return PdfStreamSource.newInstanceNoPassword(getClass().getClassLoader().getResourceAsStream(path), name);
     }
 
+    public PdfFileSource customInput(PDDocument doc, String name) {
+        try {
+            File tmp = org.sejda.core.support.io.IOUtils.createTemporaryBufferWithName(name);
+            doc.writeTo(tmp);
+            return PdfFileSource.newInstanceNoPassword(tmp);
+        } catch (TaskIOException | IOException e) {
+            throw new RuntimeException(e);
+        }
+    }
+
     public PdfStreamSource customEncryptedInput(String path, String password) {
         return PdfStreamSource.newInstanceWithPassword(getClass().getClassLoader().getResourceAsStream(path),
                 randomAlphanumeric(16) + ".pdf", password);
